nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Alias

Struct Alias 

#[repr(transparent)]
pub struct Alias(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl Alias

pub const fn data(&self) -> u32

Write next word in little-endian form. The hash requires big endian word data, but this block swaps the bytes automatically. That is, SHA assumes the data coming in is treated as bytes (e.g. “abcd”) and since the ARM core will treat “abcd” as a word as 0x64636261, the block will swap the word to restore into big endian.

pub const fn set_data(&mut self, val: u32)

Write next word in little-endian form. The hash requires big endian word data, but this block swaps the bytes automatically. That is, SHA assumes the data coming in is treated as bytes (e.g. “abcd”) and since the ARM core will treat “abcd” as a word as 0x64636261, the block will swap the word to restore into big endian.