#[repr(transparent)]pub struct Memaddr(pub u32);Expand description
Address to start memory access from (if available).
Tuple Fields
0: u32Implementations
Sourceimpl Memaddr
impl Memaddr
Sourcepub const fn base(&self) -> u32
pub const fn base(&self) -> u32
Address base to start copying from, word aligned (so bits 1:0 must be 0). This field will advance as it processes the words. If it fails with a bus error, the register will contain the failing word. N:Address in Flash or RAM space; RAM only as mapped in this part. May also be able to address SPIFI.
Sourcepub const fn set_base(&mut self, val: u32)
pub const fn set_base(&mut self, val: u32)
Address base to start copying from, word aligned (so bits 1:0 must be 0). This field will advance as it processes the words. If it fails with a bus error, the register will contain the failing word. N:Address in Flash or RAM space; RAM only as mapped in this part. May also be able to address SPIFI.