#[repr(transparent)]pub struct Alias(pub u32);Expand description
no description available
Tuple Fields
0: u32Implementations
Sourceimpl Alias
impl Alias
Sourcepub const fn data(&self) -> u32
pub const fn data(&self) -> u32
Write next word in little-endian form. The hash requires big endian word data, but this block swaps the bytes automatically. That is, SHA assumes the data coming in is treated as bytes (e.g. “abcd”) and since the ARM core will treat “abcd” as a word as 0x64636261, the block will swap the word to restore into big endian.
Sourcepub const fn set_data(&mut self, val: u32)
pub const fn set_data(&mut self, val: u32)
Write next word in little-endian form. The hash requires big endian word data, but this block swaps the bytes automatically. That is, SHA assumes the data coming in is treated as bytes (e.g. “abcd”) and since the ARM core will treat “abcd” as a word as 0x64636261, the block will swap the word to restore into big endian.